import logging

from .defaults import *
from zia import ZiaApiBase

class Gre(ZiaApiBase):
    def get_gre_tunnel_details(self):
        path = 'orgProvisioning/ipGreTunnelInfo'
        return self._output(self._session.get(path))


LOGGER = logging.getLogger(__name__)



import logging

from .defaults import *
from zia import ZiaApiBase

class User(ZiaApiBase):
    def get_departments(self):
        raise NotImplementedError()
    def get_departments_by_id(self, department_id):
        raise NotImplementedError()
    def get_groups(self):
        raise NotImplementedError()
    def get_group_by_id(self, group_id):
        raise NotImplementedError()
    def get_users(self):
        raise NotImplementedError()
    def get_user_by_id(self, user_id):
        raise NotImplementedError()
    def create_user(self, user):
        raise NotImplementedError()
    def delete_users(self, users):
        raise NotImplementedError()
    def update_user(self, user):
        raise NotImplementedError()
    def delete_user_by_id(self, user):
        raise NotImplementedError()


LOGGER = logging.getLogger(__name__)



import logging
from .defaults import *


class Datacenters(object):
    def __init__(self, session):
        self.session = session
    def get_all_vips(self):
        path = 'vips?include=all'
        return self.session.get(path)
    def get_all_public_vips(self):
        path = 'vips?include=public'
        return self.session.get(path)
    def get_all_private_vips(self):
        path = 'vips?include=private'
        return self.session.get(path)


LOGGER = logging.getLogger(__name__)



import logging

from zia import ZiaApiBase

class UrlFilteringPolicies(ZiaApiBase):
    def list(self):
        path = 'urlFilteringRules'
        return self._output(self._session.get(path))
    def create(self, rule):
        path = 'urlFilteringRules'
        return self._output(self._session.post(path, rule))
    def show(self, rule_id):
        path = 'urlFilteringRules/{}'.format(rule_id)
        return self._output(self._session.get(path))
    def update(self, rule_id, rule):
        path = 'urlFilteringRules/{}'.format(rule_id)
        return self._output(self._session.put(path, rule))
    def delete(self, rule_id):
        path = 'urlFilteringRules/{}'.format(rule_id)
        return self._output(self._session.delete(path))
    
LOGGER = logging.getLogger(__name__)
if __name__ == '__main__':
    import fire
    
    from zia.defaults import *
    from zia import load_config, ZiaApiBase
    from zia.session import Session, RequestError
    try:
        load_config()
        LOGGER.setLevel(logging.DEBUG)
        session = Session()
        policies = UrlFilteringPolicies(session, 'str')
        session.authenticate()
        fire.Fire(policies)
    except RequestError as exc:
        fmt = 'method {} path {} code {} message {} body {}'
        LOGGER.error(fmt.format(exc.method, exc.path, exc.code, exc.message, exc.body))



import logging
from .defaults import *

from zia import ZiaApiBase

class Ssl(ZiaApiBase):
    def delete_ssl_certchain(self):
        raise NotImplementedError()
    def download_csr(self):
        raise NotImplementedError()
    def generate_csr(self):
        raise NotImplementedError()
    def show_cert(self):
        raise NotImplementedError()
    def upload_signed_cert(self):
        raise NotImplementedError()
    def upload_cert_chain(self):
        raise NotImplementedError()


LOGGER = logging.getLogger(__name__)



import datetime
import logging
import json

from zia import ZiaApiBase
from .defaults import *

class AdminAuditLogs(ZiaApiBase):
    def get_auditlog_entry_report(self):
        path = 'auditlogEntryReport'
        # status complete
        # download
        return self._output(self._session.get(path))
    def generate_auditlog_entry_report(self, start, end, page, page_size):
        # start : startdatetime
        # end : enddatetime
        path = 'auditlogEntryReport'
        body = {
            # epoch in millisec
            'startTime': int(start.timestamp()*1000),
            'endTime': int(end.timestamp()*1000),
            'page': page,
            'pageSize': page_size
        }
        return self._output(self._session.post(path, body))
    def wait_for_completion(self, timeout=600):
        status = {'status':'not started yet'}
        s = datetime.datetime.now()
        while status['status'] != 'COMPLETE':
            status = self.get_auditlog_entry_report()
            e = datetime.datetime.now()
            if (e - s).seconds > timeout:
                raise RuntimeError('timeout')
        return status
    def download_auditlog_entry_report(self):
        # timezone が PDT になってる
        self.wait_for_completion()
        path = 'auditlogEntryReport/download'
        return self._output(self._session.get(path))

LOGGER = logging.getLogger(__name__)



import datetime
import json
import logging
import time
import os
import platform
import re
import requests
import sys
from http.cookiejar import Cookie

import yaml

from .defaults import *
from . import load_config

PROFILE_FILENAME = os.path.join(os.environ['HOME'], '.zscaler', 'profile.yaml')
PROFILE = 'default'

COOKIE_FILENAME = os.path.join(os.environ['HOME'], '.zscaler', 'cookie.yaml')

# constant
URL = 'url'
USERNAME = 'username'
PASSWORD = 'password'
APIKEY = 'apikey'

class RequestError(Exception):
    def __init__(self, method, path, body, error):
        self.method = method
        self.path = path
        self.body = body
        self.code = error['code']
        self.message = error['message']

class SessionTimeoutError(RequestError):
    pass

class Session(object):
    API_VERSION  = 'api/v1'
    USER_AGENT = 'zia api sdk'
    def __init__(self, profile='default'):
        self.profile = profile
        self._profile = None
        self.get_profile(name=profile)
        self.url = self._profile[URL]
        if self.url[-1] == '/':
            raise RuntimeError('url {} must not be end with "/".'.format(url))
        self.username = self._profile[USERNAME]
        self.password = self._profile[PASSWORD]
        (self.timestamp, self.obfuscated_api_key) = self._obfuscate_api_key(self._profile[APIKEY])
        self.session = requests.Session()
        self.load_cookie()
    def get_profile(self, filename=PROFILE_FILENAME, name=PROFILE, reread=False):
        if self._profile is None or reread:
            try:
                with open(filename) as file:
                    self._profile = yaml.safe_load(file)[name]
            except FileNotFoundError:
                raise RuntimeError('Cannot find profile file: {}'.format(filename))
        return self._profile
    def load_cookie(self, filename=COOKIE_FILENAME, name=PROFILE, reread=False):
        if len(self.session.cookies) == 0 or reread:
            try:
                y = None
                with open(filename) as file:
                    y = yaml.safe_load(file)
                for d in y[name].values():
                    # if d['expires'] is not None:
                    #     expiredatetime = datetime.datetime.strptime(d['expires'], '%a, %d %b %Y %H:%m:%S GMT')
                    #     if expiredatetime < datetime.datetime.utcnow():
                    #         LOGGER.warning('cookie expired : {}'.format(d['name']))
                    #     continue
                    c = Cookie(
                        d['version'],
                        d['name'],
                        d['value'],
                        d['port'],
                        d['port_specified'],
                        d['domain'],
                        d['domain_specified'],
                        d['domain_initial_dot'],
                        d['path'],
                        d['path_specified'],
                        d['secure'],
                        d['expires'],
                        d['discard'],
                        d['comment'],
                        d['comment_url'],
                        d['_rest'],
                        d['rfc2109'])
                    if c.is_expired():
                        LOGGER.warning('cookie expired : {}'.format(d['name']))
                        continue
                    d['expires'] = None
                    self.session.cookies.set_cookie(c)
            except FileNotFoundError:
                LOGGER.warning('Cannot find cookie file: {}'.format(filename))
            except KeyError:
                LOGGER.warning('Cannot find cookie profile: {}'.format(filename))
    def save_cookie(self, filename=COOKIE_FILENAME, name=PROFILE):
        y = {}
        try:
            with open(filename) as file:
                y = yaml.safe_load(file)
        except FileNotFoundError:
            pass
        if name not in y:
            y[name] = {}
        for c in self.session.cookies:
            y[name][c.name] = c.__dict__
            if c.name == 'JSESSIONID' and 'expires' in y[name][c.name]:
                # override session cookie(d['expires']==None) for cli
                # expire_datetime = datetime.datetime.utcnow() + datetime.timedelta(seconds=2*60*60)
                # y[name][c.name]['expires'] = expire_datetime.strftime('%a, %d %b %Y %H:%m:%S GMT')
                # 2 hours is no basis.
                y[name][c.name]['expires'] = int(time.time()) + 2*60*60
        with open(filename, 'w') as file:
            yaml.dump(y, file)
    def _set_header(self, cookie=None):
        header = {
            'Content-Type': 'application/json',
            'Cache-Control': 'no-cache',
            'User-Agent': self.USER_AGENT
        }
        LOGGER.debug("HTTP Header: {}".format(header))
        return header
    def _obfuscate_api_key(self, api_key):
        now = str(int(time.time() * 1000))
        n = now[-6:]
        r = str(int(n) >> 1).zfill(6)
        key = ""
        for i in range(0, len(n), 1):
            key += api_key[int(n[i])]
        for j in range(0, len(r), 1):
            key += api_key[int(r[j])+2]
        LOGGER.debug(
            "OBFUSCATED APY KEY / Time: ***** / {}".format(now))
        return (now, key)
    def authenticate(self):
        path = 'authenticatedSession'
        try:
            if self.session.cookies.get('JSESSIONID'):
                LOGGER.info("cookie authentication")
                res = self.get(path)
                # GET /authenticatedSession does not validate session(JSESSIONID cookie), so execute other method
                self.get_status()
                LOGGER.info("authenticated")
                return res
        except SessionTimeoutError:
            LOGGER.info("session timedout. trying re-authn")
        LOGGER.info("password authentication")
        body = {
            'username': self.username,
            'password': self.password,
            'apiKey': self.obfuscated_api_key,
            'timestamp': self.timestamp
        }
        LOGGER.debug("HTTP BODY: {}".format(body))
        res = self.post(path, body)
        LOGGER.debug(res)
        if not res['authType']:
            raise RuntimeError('not authenticated')
        LOGGER.info('authenticated')
        self.save_cookie()
    def get_status(self):
        path = 'status'
        return self.get(path)
    def activate(self):
        path = 'status/activate'
        return self.post(path)
    def request(self, method, path, body=None):
        header = self._set_header()
        uri = "/".join([self.url, self.API_VERSION, path])
        LOGGER.debug('method {} path {} body {}'.format(method.__name__, path, body))
        q = None
        kwargs = {
            'headers':header,
            'timeout':REQUEST_TIMEOUTS
        }
        if body:
            kwargs['json'] = body
        res_json = None
        error = None
        res = method(uri, **kwargs)
        code = {'code': res.text, 'message': res.text}
        try:
            res_json = res.json()
            error = res_json
        except json.decoder.JSONDecodeError:
            pass
        if res.ok:
            error = None
        if error:
            raise RequestError(method.__name__, path, body, error)
        if res_json:
            return res_json
        if len(res.text) == 0:
            return None
        if re.search(r'<title>Zscaler Maintenance Page</title>', res.text):
            error = {'code': 'MAINTENANCE', 'message': 'undergoing maintenance'}
            raise RequestError(method.__name__, path, body, error)
        elif re.search(r'var contentString = "Something has gone wrong while attempting to display this page.";', res.text):
            error = {'code': 'ERROR', 'message': 'Something has gone wrong'}
            raise RequestError(method.__name__, path, body, error)
        elif res.text == 'SESSION_NOT_VALID':
            error = {'code': 'SESSION_NOT_VALID', 'message': 'maybe cookie timeout'}
            raise SessionTimeoutError(method.__name__, path, body, error)
        elif re.search(r'Request body is invalid', res.text):
            error = {'code': 'REQUEST_NOT_VALID', 'message': res.text}
            raise RequestError(method.__name__, path, body, error)
        else:
            LOGGER.warning("text output might be error: {}".format(res.text))
        # it may not be OK strictly becase api dit not return json.
        return res.text
    def get(self, path):
        return self.request(self.session.get, path)
    def post(self, path, body):
        return self.request(self.session.post, path, body)
    def put(self, path, body):
        return self.request(self.session.put, path, body)
    def delete(self, path):
        return self.request(self.session.delete, path)


LOGGER = logging.getLogger(__name__)

if __name__ == '__main__':
    load_config()
    LOGGER.setLevel(logging.INFO)
    session = Session()
    LOGGER.info(session.authenticate())
    LOGGER.info(session.session.cookies.get('JSESSIONID'))
    LOGGER.info(session.authenticate())



import json

global Z_CLOUDS, DEBUG_DEFAULT, MAX_FQDN_LEN, MAX_PSK_LEN, REQUEST_TIMEOUTS

DEBUG_DEFAULT = False
MAX_FQDN_LEN = 255
MAX_PSK_LEN = 64
REQUEST_TIMEOUTS = (5, 25)

Z_CLOUDS = {
    'zscaler': 'https://admin.zscaler.net/',
    'zscloud': 'https://admin.zscloud.net/',
    'zscalerone': 'https://admin.zscalerone.net/',
    'zscalertwo': 'https://admin.zscalertwo.net/',
    'zscalerthree': 'https://admin.zscalerthree.net/',
    'betacloud': 'https://admin.zscalerbeta.net/'
}

USER_CONFIG_FILE = './config.yaml'

def load_config():
    global _CONFIG
    _CONFIG = yaml.safe_load(pkgutil.get_data(__package__, 'data/config.yaml').decode('utf-8'))
    if os.path.exists(USER_CONFIG_FILE):
        with open(USER_CONFIG_FILE) as configfile:
            _CONFIG = yaml.safe_load(configfile.read())
    if 'log' in _CONFIG:
        logging.config.dictConfig(_CONFIG['log'])

def get_config():
    if _CONFIG is None:
        load_config()
    return _CONFIG

class ZiaApiBase(object):
    def __init__(self, session, output_type='dict'):
        self._session = session
        self._output_type = output_type
    def _output(self, res):
        if self._output_type == 'dict':
            return res
        elif self._output_type == 'str':
            #for fire
            return json.dumps(res, indent=True, ensure_ascii=False)
        raise RuntimeError('unknown output_type {}'.format(self._output_type))



import fire
from zia import *

class ZscalerInternetAccess(object):
    def __init__(self, profile='default'):
        self._session = Session(profile=profile)
        # self.activation = Activation(self.session)
        # self.admin_audit_logs = AdminAuditLogs(self.session)
        # self.location = Locations(self.session)
        # self.security = Security(self.session)
        # self.datacenters = Datacenters(self.session)
        # self.sandbox = Sandbox(self.session)
        # self.ssl = Ssl(self.session)
        # self.user = User(self.session)
        # self.gre = Gre(self.session)
        # self.vpn_credentials = VpnCredentials(self.session)
        self.policies = UrlFilteringPolicies(self._session, 'str')
        self.categories = UrlCategories(self._session, 'str')
    def authenticate(self):
        self._session.authenticate()

def main():
    z = ZscalerInternetAccess()
    z.authenticate()
    fire.Fire(z)
    return 0

if __name__ == "__main__":
    main()



import logging

from zia import ZiaApiBase

class Activation(ZiaApiBase):
    def get_status(self):
        path = 'status'
        return self._output(self._session.get(path))
    def activate(self):
        path = 'status/activate'
        body = {}
        return self._output(self._session.post(path, body))


LOGGER = logging.getLogger(__name__)



import random
import string
import json
import logging

from .defaults import *
from zia import ZiaApiBase

class VpnCredentials(ZiaApiBase):
    def _randomize_psk(self):
        psk = ''.join(random.choices(
            string.ascii_letters + string.digits, k=MAX_PSK_LEN))
        LOGGER.debug("RANDOM PSK: {} (PSK Length: {})".format(
            psk,
            len(psk)
        ))
        return psk
    def extract_vpn_credential_id(self, json_response):
        data = json.loads(json_response)
        LOGGER.debug("Extract VPN ID: {}".format(data['id']))
        return data['id']
    def get_vpn_credentials(self):
        path = 'vpnCredentials'
        return self._output(self._session.get(path))
    def create_vpn_credential(self, fqdn, psk):
        path = 'vpnCredentials'
        if not fqdn:
            LOGGER.error("ERROR: {}".format("No FQDN Provided"))
            return 'No FQDN Provided'
        if psk:
            LOGGER.debug("PREDEFINED PSK: {}".format(psk))
        elif not psk:
            psk = self._randomize_psk()
        body = {
            'type': 'UFQDN',
            'fqdn': fqdn,
            'comments': 'Zscaler SDK',
            'preSharedKey': psk
        }
        return self._output(self._session.post(uri, body))
    def get_vpn_credential_by_id(self, vpn_id):
        path = 'vpnCredentials/' + str(vpn_id)
        return self._output(self._session.get(path))
    def update_vpn_credential_by_id(self, vpn_id, fqdn, psk):
        path = 'vpnCredentials/' + str(vpn_id)
        if not fqdn:
            LOGGER.error("ERROR: {}".format("No FQDN Provided"))
            return 'No FQDN Provided'
        if psk:
            LOGGER.debug("PREDEFINED PSK: {}".format(psk))
        elif not psk:
            psk = self._randomize_psk()
        body = {
            'type': 'UFQDN',
            'fqdn': fqdn,
            'comments': 'Zscaler SDK',
            'preSharedKey': psk
        }
        return self._output(self._session.put(path, body))
    def delete_vpn_credential_by_id(self, vpn_id):
        path = 'vpnCredentials/' + vpn_id
        return self._output(self._session.delete(path))


LOGGER = logging.getLogger(__name__)



import logging
from .defaults import *


class Helpers(object):
    def extract_values(self, obj, key):
        """Recursively pull values of specified key from nested JSON."""
        arr = []

        def extract(obj, arr, key):
            """Return all matching values in an object."""
            if isinstance(obj, dict):
                for k, v in obj.items():
                    if isinstance(v, (dict, list)):
                        extract(v, arr, key)
                    elif k == key:
                        arr.append(v)
            elif isinstance(obj, list):
                for item in obj:
                    extract(item, arr, key)
            return arr

        results = extract(obj, arr, key)
        return results


LOGGER = logging.getLogger(__name__)



from .defaults import load_config, get_config, ZiaApiBase
from .activation import Activation
from .admin_audit_logs import AdminAuditLogs
from .datacenters import Datacenters
from .gre import Gre
from .locations import Locations
from .security import Security
from .session import Session
from .sandbox import Sandbox
from .ssl import Ssl
from .user import User
from .vpn_credentials import VpnCredentials
from .url_filtering_policies import UrlFilteringPolicies
from .url_categories import UrlCategories



import datetime
import logging
import json
import sys

import fire

from zia.defaults import *
from zia import load_config, ZiaApiBase
from zia.session import Session, RequestError

class UrlCategories(ZiaApiBase):
    def list(self, custom_only=False):
        path = 'urlCategories'
        if custom_only:
            path += '?customOnly=true'
        return self._output(self._session.get(path))
    def create(self, category):
        path = 'urlCategories'
        return self._output(self._session.post(path, category))
    def list_lite(self):
        path = 'urlCategories/lite'
        return self._output(self._session.get(path))
    def get_quota(self):
        path = 'urlCategories/urlQuota'
        return self._output(self._session.get(path))
    def get(self, category_id):
        path = 'urlCategories/{}'.format(category_id)
        return self._output(self._session.get(path))
    def update(self, category_id, category):
        path = 'urlCategories/{}'.format(category_id)
        return self._output(self._session.put(path, category))
    def delete(self, category_id):
        path = 'urlCategories/{}'.format(category_id)
        return self._output(self._session.delete(path))
    def lookup(self, urls):
        path = 'urlLookup'
        return self._output(self._session.post(path, urls))

LOGGER = logging.getLogger(__name__)
if __name__ == '__main__':
    try:
        load_config()
        LOGGER.setLevel(logging.DEBUG)
        session = Session()
        categories = UrlCategories(session, 'str')
        session.authenticate()
        fire.Fire(categories)
    except RequestError as exc:
        fmt = 'method {} path {} code {} message {} body {}'
        LOGGER.error(fmt.format(exc.method, exc.path, exc.code, exc.message, exc.body))



import logging
import json

from .defaults import *
from zia import ZiaApiBase

class Locations(ZiaApiBase):
    def get_locations(self):
        path = 'locations'
        return self._output(self._session.get(path))
    def create_location(self, location_name, vpn_cred_id, fqdn, gateway_options=None):
        path = 'locations'
        if not vpn_cred_id:
            return 'VPN Credential ID Required'
        if not fqdn:
            return 'FQDN Required'
        body = {
            "name": location_name,
            "vpnCredentials": [
                {
                    "id": vpn_cred_id,
                    "type": "UFQDN",
                    "fqdn": fqdn
                }
            ]
        }
        if gateway_options:
            body = {**body, **gateway_options}
        return self._output(self._session.post(path, body))
    def create_sub_location(self, parent_id, location_name, ip_addresses, gateway_options=None):
        path = 'locations'
        if not parent_id:
            raise RuntimeError('Location Parent ID Required')
        if not location_name:
            raise RuntimeError('Location Name Required')
        if not ip_addresses:
            raise RuntimeError('IP Addresses Required')
        body = {
            "name": location_name,
            "parentId": parent_id,
            "ipAddresses": [
                ip_addresses
            ],
        }
        if gateway_options:
            body = {**body, **gateway_options}
        return self._output(self._session.post(path,body))
    def get_locations_lite(self):
        path = 'locations/lite'
        res = self._output(self._session.get(path))
        return res.json()
    def get_locations_by_id(self, location_id):
        if not location_id:
            return "Location Requried"
        path = 'locations/lite/' + str(location_id)
        return self._output(self._session.get(path))
    def update_location_by_id(self, location_id):
        raise NotImplementedError()
    def delete_location_by_id(self, location_id):
        raise NotImplementedError()
    def get_vpn_endpoints(self, ipv4_addr):
        raise RuntimeError('これセッションである必要があるの? エンドポイントがおかしくないか?')
        if not ipv4_addr:
            return 'IPv4 Address Requried'
        uri = 'https://pac.zscalerbeta.net/getVpnEndpoints?srcIp=' + ipv4_addr
        return self._output(self._session.sessionget(uri))


LOGGER = logging.getLogger(__name__)



import json
import logging

from zia import ZiaApiBase

class Security(ZiaApiBase):
    def get_whitelist_urls(self):
        path = 'security'
        return self._output(self._session.get(path))
    def update_whitelist_urls(self):
        raise NotImplementedError()
    def get_blacklist_urls(self):
        path = 'security/advanced'
        return self._output(self._session.get(path))
    def update_blacklist_urls(self):
        raise NotImplementedError()
    def add_blacklist_urls(self, black_list_urls):
        path = 'security/advanced/blacklistUrls?action=ADD_TO_LIST'
        body = {
            "blacklistUrls": [
            ]
        }
        for url in black_list_urls:
            body['blacklistUrls'].append(str(url))
        return self._output(self._session.post(path, body))
    def remove_blacklist_urls(self):
        raise NotImplementedError()


LOGGER = logging.getLogger(__name__)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['zia']

package_data = \
{'': ['*'], 'zia': ['data/config.yaml']}

install_requires = \
['PyYAML>=5.3.1,<6.0.0', 'fire>=0.3.1,<0.4.0', 'requests>=2.24.0,<3.0.0']

entry_points = \
{'console_scripts': ['zia = zia.__main__:main']}

setup_kwargs = {
    'name': 'zia',
    'version': '0.1.3',
    'description': 'Zscaler Internet Access CLI',
    'long_description': '# Zscaler Python SDK \n\nThis is a Python SDK for Zscaler Internet Access.  This client library is designed to support the Zscaler Internet Access (ZIA) [API](https://help.zscaler.com/zia/about-api) and [SD-WAN API](https://help.zscaler.com/zia/sd-wan-api-integration) (aka "Partner API").  All API referecnes can be found here [[LINK](https://help.zscaler.com/zia/api)].  **PLEASE READ THE DOCUMENTATION BEFORE CONTACTING ZSCALER**\n\nThis SDK has been developed mainly using Python 3.8.5 on Ubuntu 20.04 LTS (Focal Fossa).\n\n**NOTE:** This repository will experience frequent updates.  To minimize breakage, public method names will not change.  If you run into any defects, please open issues [[HERE.](https://github.com/omitroom13/zia/issues)]\n\n## Quick Start \n\n1) If you have not verified your credentials, we suggest starting [[HERE](https://help.zscaler.com/zia/configuring-postman-rest-api-client)], unless you are already familar with this API.\n\n2) Set profile\n \n```\n$ mkdir ~/.zscaler\n$ cat > ~/.zscaler/profile.yaml <<EOF\ndefault:\n  url: https://admin.<ZIA-CLOUD>.net\n  username: <ZIA-ADMIN-USER-ID>\n  password: <ZIA-ADMIN-USER-PASSWORD>\n  apikey: <ZIA-API-KEY>\npartner:\n  url: https://admin.<ZIA-CLOUD>.net\n  username: <ZIA-PARTNER-ADMIN-USER-ID>\n  password: <ZIA-PARTNER-ADMIN-USER-PASSWORD>\n  apikey: <PARTNER-API-KEY>\nEOF\n```\n        \n3) Clone Repository (OS must have git installed)\n\n```\n$ git clone https://github.com/omitroom13/zia.git\n$ cd zia/\n```\n\n4) Install SDK requirements (OS must have python3 installed)\n\n```\n$ pip install -r requirements.txt\n```\n\n5) Install SDK\n\n```\n$ python setup.py install\n```\n\n6) Check out examples\n\n```\n$ ls examples/\n...\n```\n\n## API Support\n\n### SD-WAN (Partner) API\n\n* **VPN Credentials**\n* **Locations**\n* **Activate**\n\n## Licensing\n\nThis work is released under the MIT license, forked from [eparra\'s zscaler-python-sdk v0.5](https://github.com/eparra/zscaler-python-sdk/). A copy of the license is provided in the [LICENSE](https://github.com/omitroom13/zia/blob/master/LICENSE) file.\n\n## Reporting Issues\n\nIf you have bugs or other issues specifically pertaining to this library, file them [here](https://github.com/omitroom13/zia/issues).\n\n## References\n\n* https://help.zscaler.com/zia/api\n* https://help.zscaler.com/zia/zscaler-api-developer-guide\n* https://help.zscaler.com/zia/sd-wan-api-integration\n',
    'author': 'omitroom13',
    'author_email': None,
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/omitroom13',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)



import logging

from .defaults import *
from .helpers import Helpers
from zia import ZiaApiBase

class Sandbox(ZiaApiBase):
    def _do_get_sanbox_report_md5(self, md5hash, report_type):
        path = 'sandbox/report/' + str(md5hash)
        if report_type == 'FULL':
            path += '?details=full'
        else:
            path += '?details=summary'
        res = self.get(path)
        if 'Retry-After' in res:
            LOGGER.error("Zscaler RATE LIMIT REACHED")
            return None
        else:
            return res
    def get_sanbox_report_md5(self, md5hash):
        res = self._do_get_sanbox_report_md5(md5hash, 'FULL')
        return res
    def get_sanbox_report_md5_summary(self, md5hash):
        res = self._do_get_sanbox_report_md5(md5hash, 'SUMMARY')
        return res
    def get_sanbox_report_sha1(self):
        raise NotImplementedError()
    def get_sanbox_report_sha256(self):
        raise NotImplementedError()
    def is_md5hash_suspicious(self, report):
        extrated = (Helpers.extract_values(report, 'Type'))
        if 'SUSPICIOUS' in extrated:
            return True
        else:
            return False
    def is_md5hash_malicious(self, report):
        extrated = (Helpers.extract_values(report, 'Type'))
        if 'MALICIOUS' in extrated:
            return True
        else:
            return False


LOGGER = logging.getLogger(__name__)
